Struct UtreexoProofMask

pub struct UtreexoProofMask(u8);
The UtreexoProofMask can be used to specify which parts of the proof data to request.

A UtreexoProof is composed of three parts:

  • Proof Hashes: the hashes that compose the Merkle proof, used to recompute the Utreexo forest’s roots.
  • Leaf Data: the data associated with the UTXOs being spent, such as the [bitcoin::Amount] being spent and the ScriptPubKey.
  • Targets: the position indexes in the Utreexo forest for the UTXOs being spent, used to recompute the forest roots.

The UtreexoProofMask’s bits can be set depending on what data you want to request.

Tuple Fields

0: u8

Implementations

Source

impl UtreexoProofMask

const TARGETS: u8 = 1u8

Whether to include the targets in the proof.

const PROOF_HASHES: u8 = 2u8

Whether to include the proof hashes in the proof.

const LEAF_DATA: u8 = 4u8

Whether to include the leaf data in the proof.

const ALL: u8 = 7u8

Request everything

pub fn new() -> Self

Creates a new empty UtreexoProofMask, with no fields selected.

Use the include_* methods to select which fields to include, or UtreexoProofMask::request_all to include all fields.

pub fn request_all() -> Self

Creates a new UtreexoProofMask that requests all fields.

This is a special constructor for the common case where you want to request all fields in the proof. If your goal is to request specific fields, use the UtreexoProofMask::new constructor and the include_* methods to choose what you need.

pub fn request_targets(self) -> Self

Whether to include the targets in the proof.

pub fn request_proof_hashes(self) -> Self

Whether to include the proof hashes in the proof.

pub fn request_leaf_data(self) -> Self

Whether to include the leaf data in the proof.