pub struct UtreexoProofMask(u8);Expand description
The UtreexoProofMask can be used to specify which parts of the proof data to request.
A UtreexoProof is composed of three parts:
- Proof Hashes: the hashes that compose the Merkle proof, used to recompute the Utreexo forest’s roots.
- Leaf Data: the data associated with the UTXOs being spent,
such as the [
bitcoin::Amount] being spent and the ScriptPubKey. - Targets: the position indexes in the Utreexo forest for the UTXOs being spent, used to recompute the forest roots.
The UtreexoProofMask’s bits can be set depending on what data you want to request.
Tuple Fields
0: u8Implementations
Sourceimpl UtreexoProofMask
impl UtreexoProofMask
Sourceconst PROOF_HASHES: u8 = 2u8
const PROOF_HASHES: u8 = 2u8
Whether to include the proof hashes in the proof.
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new empty UtreexoProofMask, with no fields selected.
Use the include_* methods to select which fields to include, or
UtreexoProofMask::request_all to include all fields.
Sourcepub fn request_all() -> Self
pub fn request_all() -> Self
Creates a new UtreexoProofMask that requests all fields.
This is a special constructor for the common case where you want to request
all fields in the proof. If your goal is to request specific fields, use the
UtreexoProofMask::new constructor and the include_* methods to choose
what you need.
Sourcepub fn request_targets(self) -> Self
pub fn request_targets(self) -> Self
Whether to include the targets in the proof.
Sourcepub fn request_proof_hashes(self) -> Self
pub fn request_proof_hashes(self) -> Self
Whether to include the proof hashes in the proof.
Sourcepub fn request_leaf_data(self) -> Self
pub fn request_leaf_data(self) -> Self
Whether to include the leaf data in the proof.